import QtQuick
import QtQuick.Controls
import QtQuick.Layouts
import QtQuick.Studio.Components
import QtQuick.Studio.DesignEffects
import DesignEffectsDemo

Item {
    id: root
    width: 1032
    height: 1080

    property list<string> numbers: []
    property list<string> inputArray1: []
    property list<string> inputArray2: []

    property string operator: ""
    property real blurFactor: 1 // blurDial.value
    //property real spreadFactor: spreadDial.value
    //property bool effectsOn: effectsSwitch.checked
    //property bool isDark: false
    Rectangle {
        id: mainBackground
        color: themeEngine.mainBackground
        anchors.fill: parent
        anchors.leftMargin: 0
        anchors.rightMargin: 0
        anchors.topMargin: 0
        anchors.bottomMargin: 0

        CalcDial {
            id: blurDial
            x: 38
            y: 361
            value: 1
            effectsOn: effectsSwitch.checked
            shadowDepth: shadowDepthControl.value
            stepSize: 0.1
            to: 2
            from: 0
            highlightFront: themeEngine.highButton1
            highlightBack: themeEngine.highButton2
            blurFactor: blurDial.value
            spreadFactor: spreadDial.value
        }

        ActiveIndicator {
            id: aciveIndicatorBlur
            y: 36
            anchors.bottom: blurDial.top
            anchors.bottomMargin: 10
            isActive: blurDial.pressed
            anchors.horizontalCenter: blurDial.horizontalCenter
        }

        Text {
            id: blurLabel
            color: themeEngine.surfaceText
            text: qsTr("BLUR")
            anchors.top: blurDial.bottom
            anchors.topMargin: 10
            font.pixelSize: 18
            anchors.horizontalCenter: blurDial.horizontalCenter
            font.family: "Victor Mono"
            DesignEffect {
                id: designEffectSL1
                visible: root.effectsOn
                layerBlurRadius: 1.5 * root.blurFactor

                effects: [
                    DesignDropShadow {
                        id: designDropShadowSL1
                        blur: 1 * root.blurFactor
                        offsetX: 0
                        offsetY: 0
                        color: themeEngine.surfaceText
                    }
                ]
            }
        }

        CalcDial {
            id: spreadDial
            x: 723
            y: 361
            value: 2.5
            highlightBack: themeEngine.mainHighlight1
            shadeFactor: 1.5
            stepSize: 0.1
            to: 10
            from: 0
            highlightFront: themeEngine.mainHighlight2
            effectsOn: effectsSwitch.checked
            shadowDepth: shadowDepthControl.value
            blurFactor: blurDial.value
            spreadFactor: spreadDial.value
        }

        CalcDial {
            id: volumeDial
            x: 855
            y: 361
            value: 0.5
            stepSize: 0.1
            to: 1
            shadeFactor: 2.5
            highlightBack: "#313131"
            highlightFront: "#2b2b2b"
            effectsOn: effectsSwitch.checked
            shadowDepth: shadowDepthControl.value
            blurFactor: blurDial.value
            spreadFactor: spreadDial.value
        }

        CalcButton {
            id: kickButton
            x: 723
            y: 783
            buttonKeyText: "KCK"
            highlightFrontBottom: themeEngine.mainHighlight1
            highlightFrontTop: themeEngine.mainHighlight2
            buttonKeyColor: themeEngine.lowButtonText
            effectsOn: effectsSwitch.checked
            spreadFactor: spreadDial.value
            blurFactor: blurDial.value
            shadowDepth: shadowDepthControl.value
        }

        CalcButton {
            id: clearButton
            x: 855
            y: 911
            buttonKeyText: "CLR"
            effectsOn: effectsSwitch.checked
            spreadFactor: spreadDial.value
            blurFactor: blurDial.value
            highlightFrontTop: themeEngine.lowButton1
            highlightFrontBottom: themeEngine.lowButton2
            buttonKeyColor: themeEngine.lowButtonText
            shadowDepth: shadowDepthControl.value
        }

        ActiveIndicator {
            id: aciveIndicatorTheme
            y: 36
            anchors.bottom: shadowDepthControl.top
            anchors.bottomMargin: 10
            isActive: shadowDepthControl.pressed
            anchors.horizontalCenter: shadowDepthControl.horizontalCenter
        }

        CalcButton {
            id: themeSwitch
            x: 855
            y: 274
            width: 100
            height: 49
            buttonKeyFontpixelSize: 22
            checkable: true
            buttonKeyText: "DARK"
            effectsOn: effectsSwitch.checked
            buttonKeyColor: themeEngine.midButtonText
            highlightFrontBottom: themeEngine.midButton2
            highlightFrontTop: themeEngine.midButton1
            spreadFactor: spreadDial.value
            blurFactor: blurDial.value
            shadowDepth: shadowDepthControl.value
        }

        ActiveIndicator {
            id: aciveIndicatorShadow
            y: 36
            anchors.bottom: themeSwitch.top
            anchors.bottomMargin: 10
            isActive: (themeSwitch.pressed || themeSwitch.checked)
            anchors.horizontalCenter: themeSwitch.horizontalCenter
        }

        CalcSlider {
            id: shadowDepthControl
            x: 43
            y: 534
            value: 1
            stepSize: 0.01
            orientation: Qt.Vertical
            to: 1.25
            from: -1
            effectsOn: effectsSwitch.checked
            aSpread: spreadDial.value
            shadowDepth: shadowDepthControl.value
        }

        Text {
            id: blurLabel1
            color: themeEngine.surfaceText
            text: qsTr("SHADOW DIR")
            anchors.top: shadowDepthControl.bottom
            anchors.topMargin: 10
            font.pixelSize: 18
            font.family: "Victor Mono"
            anchors.horizontalCenter: shadowDepthControl.horizontalCenter
            DesignEffect {
                id: designEffectSL2
                visible: root.effectsOn
                layerBlurRadius: 1.5 * root.blurFactor

                effects: [
                    DesignDropShadow {
                        id: designDropShadowSL2
                        blur: 1 * root.blurFactor
                        offsetX: 0
                        offsetY: 0
                        color: themeEngine.surfaceText
                    }
                ]
            }
        }

        RowLayout {
            x: 177
            y: 534
            spacing: 32
            ColumnLayout {
                spacing: 25
                CalcButton {
                    id: percentButton
                    buttonKeyColor: themeEngine.highButtonText
                    buttonKeyText: "%"
                    highlightFrontTop: themeEngine.highButton1
                    highlightFrontBottom: themeEngine.highButton2
                    effectsOn: effectsSwitch.checked
                    spreadFactor: spreadDial.value
                    blurFactor: blurDial.value
                    shadowDepth: shadowDepthControl.value
                }

                CalcButton {
                    id: divideButton
                    buttonKeyText: "/"
                    effectsOn: effectsSwitch.checked
                    spreadFactor: spreadDial.value
                    blurFactor: blurDial.value
                    highlightFrontTop: themeEngine.highButton1
                    highlightFrontBottom: themeEngine.highButton2
                    buttonKeyColor: themeEngine.highButtonText
                    shadowDepth: shadowDepthControl.value
                }

                CalcButton {
                    id: multButton
                    buttonKeyText: "*"
                    effectsOn: effectsSwitch.checked
                    spreadFactor: spreadDial.value
                    blurFactor: blurDial.value
                    highlightFrontTop: themeEngine.highButton1
                    highlightFrontBottom: themeEngine.highButton2
                    buttonKeyColor: themeEngine.highButtonText
                    shadowDepth: shadowDepthControl.value
                }

                CalcButton {
                    id: minusButton
                    buttonKeyText: "-"
                    effectsOn: effectsSwitch.checked
                    spreadFactor: spreadDial.value
                    blurFactor: blurDial.value
                    highlightFrontTop: themeEngine.highButton1
                    highlightFrontBottom: themeEngine.highButton2
                    buttonKeyColor: themeEngine.highButtonText
                    shadowDepth: shadowDepthControl.value
                }
            }

            ColumnLayout {
                spacing: 25
                CalcButton {
                    id: num1
                    buttonKeyColor: themeEngine.midButtonText
                    highlightFrontBottom: themeEngine.midButton2
                    highlightFrontTop: themeEngine.midButton1
                    buttonKeyText: "1"
                    effectsOn: effectsSwitch.checked
                    spreadFactor: spreadDial.value
                    blurFactor: blurDial.value
                    shadowDepth: shadowDepthControl.value
                }

                CalcButton {
                    id: num4
                    buttonKeyText: "4"
                    buttonKeyColor: themeEngine.midButtonText
                    highlightFrontBottom: themeEngine.midButton2
                    highlightFrontTop: themeEngine.midButton1
                    effectsOn: effectsSwitch.checked
                    spreadFactor: spreadDial.value
                    blurFactor: blurDial.value
                    shadowDepth: shadowDepthControl.value
                }

                CalcButton {
                    id: num7
                    buttonKeyText: "7"
                    buttonKeyColor: themeEngine.midButtonText
                    highlightFrontBottom: themeEngine.midButton2
                    highlightFrontTop: themeEngine.midButton1
                    effectsOn: effectsSwitch.checked
                    spreadFactor: spreadDial.value
                    blurFactor: blurDial.value
                    shadowDepth: shadowDepthControl.value
                }

                CalcButton {
                    id: plusButton
                    buttonKeyText: "+"
                    effectsOn: effectsSwitch.checked
                    spreadFactor: spreadDial.value
                    blurFactor: blurDial.value
                    highlightFrontTop: themeEngine.highButton1
                    highlightFrontBottom: themeEngine.highButton2
                    buttonKeyColor: themeEngine.highButtonText
                    shadowDepth: shadowDepthControl.value
                }
            }

            ColumnLayout {
                spacing: 25

                CalcButton {
                    id: num5
                    buttonKeyText: "5"
                    buttonKeyColor: themeEngine.midButtonText
                    highlightFrontBottom: themeEngine.midButton2
                    highlightFrontTop: themeEngine.midButton1
                    effectsOn: effectsSwitch.checked
                    spreadFactor: spreadDial.value
                    blurFactor: blurDial.value
                    shadowDepth: shadowDepthControl.value
                    Connections {
                        target: num5
                        onClicked: digitHandler.sendDigit(5)
                    }
                }

                CalcButton {
                    id: num8
                    buttonKeyText: "8"
                    buttonKeyColor: themeEngine.midButtonText
                    highlightFrontBottom: themeEngine.midButton2
                    highlightFrontTop: themeEngine.midButton1
                    effectsOn: effectsSwitch.checked
                    spreadFactor: spreadDial.value
                    blurFactor: blurDial.value
                    shadowDepth: shadowDepthControl.value
                    Connections {
                        target: num8
                        onClicked: digitHandler.sendDigit(8)
                    }
                }

                CalcButton {
                    id: num0
                    buttonKeyText: "0"
                    effectsOn: effectsSwitch.checked
                    highlightFrontTop: themeEngine.highButton1
                    highlightFrontBottom: themeEngine.highButton2
                    spreadFactor: spreadDial.value
                    blurFactor: blurDial.value
                    shadowDepth: shadowDepthControl.value

                    Connections {
                        target: num0
                        onClicked: digitHandler.sendDigit(0)
                    }
                }
            }

            ColumnLayout {
                spacing: 25
                CalcButton {
                    id: num3
                    buttonKeyText: "3"
                    buttonKeyColor: themeEngine.midButtonText
                    highlightFrontBottom: themeEngine.midButton2
                    highlightFrontTop: themeEngine.midButton1
                    effectsOn: effectsSwitch.checked
                    spreadFactor: spreadDial.value
                    blurFactor: blurDial.value
                    shadowDepth: shadowDepthControl.value
                }

                CalcButton {
                    id: num6
                    buttonKeyText: "6"
                    buttonKeyColor: themeEngine.midButtonText
                    highlightFrontBottom: themeEngine.midButton2
                    highlightFrontTop: themeEngine.midButton1
                    effectsOn: effectsSwitch.checked
                    spreadFactor: spreadDial.value
                    blurFactor: blurDial.value
                    shadowDepth: shadowDepthControl.value
                }

                CalcButton {
                    id: num9
                    buttonKeyText: "9"
                    buttonKeyColor: themeEngine.midButtonText
                    highlightFrontBottom: themeEngine.midButton2
                    highlightFrontTop: themeEngine.midButton1
                    effectsOn: effectsSwitch.checked
                    spreadFactor: spreadDial.value
                    blurFactor: blurDial.value
                    shadowDepth: shadowDepthControl.value
                }

                CalcButton {
                    id: happy
                    buttonKeyText: ":)"
                    effectsOn: effectsSwitch.checked
                    spreadFactor: spreadDial.value
                    blurFactor: blurDial.value
                    highlightFrontTop: themeEngine.highButton1
                    highlightFrontBottom: themeEngine.highButton2
                    buttonKeyColor: themeEngine.highButtonText
                    shadowDepth: shadowDepthControl.value
                }
            }
        }

        CalcButton {
            id: sumButton
            x: 723
            y: 911
            buttonKeyText: "SUM"
            effectsOn: effectsSwitch.checked
            spreadFactor: spreadDial.value
            blurFactor: blurDial.value
            highlightFrontTop: themeEngine.mainHighlight2
            highlightFrontBottom: themeEngine.mainHighlight1
            buttonKeyColor: themeEngine.lowButtonText
            shadowDepth: shadowDepthControl.value
        }

        CalcButton {
            id: wompButton
            x: 855
            y: 783
            buttonKeyText: "WMP"
            effectsOn: effectsSwitch.checked
            spreadFactor: spreadDial.value
            blurFactor: blurDial.value
            highlightFrontTop: themeEngine.lowButton1
            highlightFrontBottom: themeEngine.lowButton2
            buttonKeyColor: themeEngine.lowButtonText
            shadowDepth: shadowDepthControl.value
        }

        ActiveIndicator {
            id: aciveIndicatorFX
            y: 36
            anchors.bottom: effectsSwitch.top
            anchors.bottomMargin: 10
            isActive: effectsSwitch.pressed || effectsSwitch.checked
            anchors.horizontalCenter: effectsSwitch.horizontalCenter
        }

        CalcButton {
            id: effectsSwitch
            x: 723
            y: 274
            width: 100
            height: 49
            checked: true
            effectsOn: effectsSwitch.checked
            checkable: true
            buttonKeyText: "FX"
            buttonKeyFontpixelSize: 22
            buttonKeyColor: themeEngine.midButtonText
            highlightFrontBottom: themeEngine.midButton2
            highlightFrontTop: themeEngine.midButton1
            spreadFactor: spreadDial.value
            blurFactor: blurDial.value
            shadowDepth: shadowDepthControl.value
        }

        CalcButton {
            id: muteSwitch
            x: 723
            y: 627
            width: 100
            height: 49
            checkable: true
            checked: true
            buttonKeyText: "MUTE"
            buttonKeyFontpixelSize: 22
            effectsOn: effectsSwitch.checked
            spreadFactor: spreadDial.value
            blurFactor: blurDial.value
            shadowDepth: shadowDepthControl.value
            buttonKeyColor: themeEngine.highButtonText
            highlightFrontBottom: themeEngine.highButton2
            highlightFrontTop: themeEngine.highButton1
        }

        ActiveIndicator {
            id: aciveIndicatorSobel
            y: 36
            anchors.bottom: sobelSwitch.top
            anchors.bottomMargin: 10
            isActive: sobelSwitch.pressed || sobelSwitch.checked
            anchors.horizontalCenter: sobelSwitch.horizontalCenter
        }

        CalcButton {
            id: orthoSwitch
            x: 855
            y: 536
            width: 100
            height: 49
            checkable: true
            buttonKeyText: "ORTHO"
            buttonKeyFontpixelSize: 22
            effectsOn: effectsSwitch.checked
            spreadFactor: spreadDial.value
            blurFactor: blurDial.value
            highlightFrontTop: themeEngine.lowButton1
            highlightFrontBottom: themeEngine.lowButton2
            buttonKeyColor: themeEngine.lowButtonText
            shadowDepth: shadowDepthControl.value
        }

        CalcButton {
            id: chordsSwitch
            x: 855
            y: 627
            width: 100
            height: 49
            checkable: true
            buttonKeyText: "CHRD"
            buttonKeyFontpixelSize: 22
            effectsOn: effectsSwitch.checked
            spreadFactor: spreadDial.value
            blurFactor: root.blurFactor
            highlightFrontTop: themeEngine.lowButton1
            highlightFrontBottom: themeEngine.lowButton2
            buttonKeyColor: themeEngine.lowButtonText
            shadowDepth: shadowDepthControl.value
        }

        ActiveIndicator {
            id: aciveIndicatorOrtho
            y: 36
            anchors.bottom: orthoSwitch.top
            anchors.bottomMargin: 10
            isActive: orthoSwitch.pressed || orthoSwitch.checked
            anchors.horizontalCenter: orthoSwitch.horizontalCenter
        }

        CalcButton {
            id: sobelSwitch
            x: 723
            y: 536
            width: 100
            height: 49
            highlightFrontTop: themeEngine.highButton1
            highlightFrontBottom: themeEngine.highButton2
            effectsOn: effectsSwitch.checked
            spreadFactor: spreadDial.value
            blurFactor: root.blurFactor
            checkable: true
            buttonKeyText: "SOBEL"
            buttonKeyFontpixelSize: 22
            buttonKeyColor: themeEngine.highButtonText
            shadowDepth: shadowDepthControl.value
        }

        Text {
            id: spreadLabel
            color: themeEngine.surfaceText
            text: qsTr("SPREAD")
            anchors.top: spreadDial.bottom
            anchors.topMargin: 10
            font.pixelSize: 18
            font.family: "Victor Mono"
            anchors.horizontalCenter: spreadDial.horizontalCenter
            DesignEffect {
                id: designEffectSL3
                visible: root.effectsOn
                layerBlurRadius: 1.5 * root.blurFactor

                effects: [
                    DesignDropShadow {
                        id: designDropShadowSL3
                        blur: 1 * root.blurFactor
                        offsetX: 0
                        offsetY: 0
                        color: themeEngine.surfaceText
                    }
                ]
            }
        }

        ActiveIndicator {
            id: aciveIndicatorSpread
            y: 36
            anchors.bottom: volumeDial.top
            anchors.bottomMargin: 10
            isActive: volumeDial.pressed
            anchors.horizontalCenter: volumeDial.horizontalCenter
        }

        STOIC {
            id: stoic
            x: 195
            y: 240
            effectsOn: effectsSwitch.checked
            blurFactor: root.blurFactor
            dark: themeSwitch.checked
        }

        Text {
            id: volumeLabel
            color: themeEngine.surfaceText
            text: qsTr("VOLUME")
            anchors.top: volumeDial.bottom
            anchors.topMargin: 10
            font.pixelSize: 18
            anchors.horizontalCenter: volumeDial.horizontalCenter
            font.family: "Victor Mono"
            DesignEffect {
                id: designEffectSL4
                visible: root.effectsOn
                layerBlurRadius: 1.5 * root.blurFactor
                effects: [
                    DesignDropShadow {
                        id: designDropShadowSL4
                        offsetY: 0
                        blur: 1 * root.blurFactor
                        offsetX: 0
                        color: themeEngine.surfaceText
                    }
                ]
            }
        }

        ActiveIndicator {
            id: aciveIndicatorMute
            y: 36
            anchors.bottom: muteSwitch.top
            anchors.bottomMargin: 10
            isActive: muteSwitch.pressed || muteSwitch.checked
            anchors.horizontalCenter: muteSwitch.horizontalCenter
        }

        ActiveIndicator {
            id: aciveIndicatorChord
            y: 36
            anchors.bottom: chordsSwitch.top
            anchors.bottomMargin: 10
            isActive: chordsSwitch.pressed || chordsSwitch.checked
            anchors.horizontalCenter: chordsSwitch.horizontalCenter
        }

        ActiveIndicator {
            id: aciveIndicatorVolume
            y: 36
            anchors.bottom: spreadDial.top
            anchors.bottomMargin: 10
            isActive: spreadDial.pressed
            anchors.horizontalCenter: spreadDial.horizontalCenter
        }

        CalcButton {
            id: dubSwitch
            x: 855
            y: 711
            width: 100
            height: 49
            spreadFactor: spreadDial.value
            highlightFrontTop: themeEngine.lowButton1
            highlightFrontBottom: themeEngine.lowButton2
            effectsOn: effectsSwitch.checked
            checkable: true
            buttonKeyText: "DUB"
            buttonKeyFontpixelSize: 22
            buttonKeyColor: themeEngine.lowButtonText
            blurFactor: root.blurFactor
            shadowDepth: shadowDepthControl.value
        }

        ActiveIndicator {
            id: aciveIndicatorDub
            y: 36
            anchors.bottom: dubSwitch.top
            anchors.bottomMargin: 10
            isActive: dubSwitch.pressed || dubSwitch.checked
            anchors.horizontalCenter: dubSwitch.horizontalCenter
        }

        CalcButton {
            id: techSwitch
            x: 723
            y: 711
            width: 100
            height: 49
            spreadFactor: spreadDial.value
            highlightFrontTop: themeEngine.lowButton1
            highlightFrontBottom: themeEngine.lowButton2
            effectsOn: effectsSwitch.checked
            shadowDepth: shadowDepthControl.value

            Connections {
                target: techSwitch
                onToggled: if (techSwitch.checked) {
                               chordsSwitch.checked = false
                               dubSwitch.checked = false
                               musicBox.source = "../../sounds/tech.wav"
                               musicBox.play()
                           } else if (!techSwitch.checked) {
                               musicBox.stop()
                           }
            }
            checkable: true
            buttonKeyText: "TECH"
            buttonKeyFontpixelSize: 22
            buttonKeyColor: themeEngine.lowButtonText
            blurFactor: root.blurFactor
        }

        ActiveIndicator {
            id: aciveIndicatorTech
            x: -132
            y: 36
            anchors.bottom: techSwitch.top
            anchors.bottomMargin: 10
            isActive: (techSwitch.pressed || techSwitch.checked)
            anchors.horizontalCenter: techSwitch.horizontalCenter
        }
    }

    Rectangle {
        id: displayPanel
        height: 230
        color: "#000000"
        anchors.left: parent.left
        anchors.right: parent.right
        anchors.top: parent.top
        anchors.leftMargin: 0
        anchors.topMargin: 0

        DesignEffect {
            id: designEffectDisplayPanel
            visible: effectsSwitch.checked
            layerBlurRadius: 1

            effects: [
                DesignDropShadow {
                    id: designDropShadowPanel
                    blur: 10
                    offsetX: 0
                    offsetY: 9
                    color: "#7e000000"
                    spread: 0
                }
            ]
        }
    }

    Glass {
        id: glass
        x: 177
        y: 286
        highlightFront: themeEngine.mainHighlight1
        pulse: (chordsSwitch.checked || dubSwitch.checked || techSwitch.checked)
        timing: 600
        effectsOn: effectsSwitch.checked
    }

    Item {
        id: dialReadouts
        x: 0
        y: 0
        width: 219
        height: 230

        DialReadout {
            id: blurDiaReadout
            x: 36
            y: 5
            progress: blurDial.value * 50
            labelText: "BLUR"
            highlightColor1: themeEngine.mainHighlight1
            readoutLabelColor: "#46a0f9"
            blurFactor: root.blurFactor
            effectsOn: effectsSwitch.checked
        }

        DialReadout {
            id: spreadDialReadout
            x: 36
            y: 80
            readoutLabelColor: "#46a0f9"
            progress: spreadDial.value * 10
            labelText: "SPREAD"
            highlightColor1: themeEngine.mainHighlight1
            blurFactor: root.blurFactor
            effectsOn: effectsSwitch.checked
        }

        DialReadout {
            id: volumeDialReadout
            x: 36
            y: 153
            readoutLabelColor: "#46a0f9"
            progress: volumeDial.value * 100
            labelText: "VOLUME"
            highlightColor1: themeEngine.mainHighlight1
            blurFactor: root.blurFactor
            effectsOn: effectsSwitch.checked
        }
    }

    Row {
        id: segDisplayGhost
        x: 250
        y: 60
        opacity: 0.153

        SevenSegChar {
            id: sevenSegChar1
            highlight: "#fcfcfc"
        }

        SevenSegChar {
            id: sevenSegChar2
            highlight: "#fcfcfc"
        }

        SevenSegChar {
            id: sevenSegChar3
            highlight: "#fcfcfc"
        }

        SevenSegChar {
            id: sevenSegChar4
            highlight: "#fcfcfc"
        }

        SevenSegChar {
            id: sevenSegChar5
            highlight: "#fcfcfc"
        }

        SevenSegChar {
            id: sevenSegChar6
            highlight: "#fcfcfc"
        }

        SevenSegChar {
            id: sevenSegChar7
            highlight: "#fcfcfc"
        }

        SevenSegChar {
            id: sevenSegChar8
            highlight: "#fcfcfc"
        }
    }

    Row {
        id: segmentDisplay
        x: 250
        y: 60
        Repeater {
            id: myrep
            model: root.numbers
            SevenSegChar {
                id: sevenSegChar
                highlight: themeEngine.mainHighlight1
                segState: modelData
                blurFactor: blurDial.value
            }
        }
    }

    Row {
        id: operatorSymbols
        x: 268
        y: 150
        spacing: 10
        Text {
            id: plus
            visible: false
            color: themeEngine.mainHighlight1
            text: "+"
            font.pixelSize: 30
            horizontalAlignment: Text.AlignHCenter
            verticalAlignment: Text.AlignVCenter
            DesignEffect {
                id: designEffectDisplayReadoutTheme3
                visible: effectsSwitch.checked
                layerBlurRadius: 2 * root.blurFactor
                effects: [
                    DesignDropShadow {
                        id: designDropShadowReadoutTheme3
                        offsetY: 0
                        blur: 3 * root.blurFactor
                        offsetX: 0
                        color: themeEngine.mainHighlight1
                    }
                ]
            }
        }

        Text {
            id: minus
            visible: minusButton.pressed
            color: themeEngine.mainHighlight1
            text: "-"
            font.pixelSize: 30
            horizontalAlignment: Text.AlignHCenter
            verticalAlignment: Text.AlignVCenter
            DesignEffect {
                id: designEffectDisplayReadoutTheme5
                visible: effectsSwitch.checked
                layerBlurRadius: 2 * root.blurFactor
                effects: [
                    DesignDropShadow {
                        id: designDropShadowReadoutTheme5
                        offsetY: 0
                        blur: 3 * root.blurFactor
                        offsetX: 0
                        color: themeEngine.mainHighlight1
                    }
                ]
            }
        }

        Text {
            id: mult
            visible: false
            color: themeEngine.mainHighlight1
            text: "*"
            font.pixelSize: 30
            horizontalAlignment: Text.AlignHCenter
            verticalAlignment: Text.AlignVCenter
            DesignEffect {
                id: designEffectDisplayReadoutTheme9
                visible: effectsSwitch.checked
                layerBlurRadius: 2 * root.blurFactor
                effects: [
                    DesignDropShadow {
                        id: designDropShadowReadoutTheme9
                        offsetY: 0
                        blur: 3 * root.blurFactor
                        offsetX: 0
                        color: themeEngine.mainHighlight1
                    }
                ]
            }
        }

        Text {
            id: div
            visible: false
            color: themeEngine.mainHighlight1
            text: "/"
            font.pixelSize: 30
            horizontalAlignment: Text.AlignHCenter
            verticalAlignment: Text.AlignVCenter
            DesignEffect {
                id: designEffectDisplayReadoutTheme10
                visible: effectsSwitch.checked
                layerBlurRadius: 2 * root.blurFactor
                effects: [
                    DesignDropShadow {
                        id: designDropShadowReadoutTheme10
                        offsetY: 0
                        blur: 3 * root.blurFactor
                        offsetX: 0
                        color: themeEngine.mainHighlight1
                    }
                ]
            }
        }

        Text {
            id: percent
            visible: false
            color: themeEngine.mainHighlight1
            text: "%"
            font.pixelSize: 30
            horizontalAlignment: Text.AlignHCenter
            verticalAlignment: Text.AlignVCenter
            DesignEffect {
                id: designEffectDisplayReadoutTheme11
                visible: effectsSwitch.checked
                layerBlurRadius: 2 * root.blurFactor
                effects: [
                    DesignDropShadow {
                        id: designDropShadowReadoutTheme11
                        offsetY: 0
                        blur: 3 * root.blurFactor
                        offsetX: 0
                        color: themeEngine.mainHighlight1
                    }
                ]
            }
        }
    }

    Item {
        id: calcOpsPanel
        x: 572
        y: 154
        width: 200
        height: 40

        Text {
            id: clear
            x: -64
            visible: false
            color: themeEngine.mainHighlight1
            text: "CLEAR"
            anchors.verticalCenter: parent.verticalCenter
            anchors.right: maxOps.left
            anchors.rightMargin: 10
            font.pixelSize: 18
            DesignEffect {
                id: designEffectDisplayReadoutTheme8
                visible: effectsSwitch.checked
                layerBlurRadius: 2 * root.blurFactor
                effects: [
                    DesignDropShadow {
                        id: designDropShadowReadoutTheme8
                        offsetY: 0
                        blur: 3 * root.blurFactor
                        offsetX: 0
                        color: themeEngine.mainHighlight1
                    }
                ]
            }
        }

        Text {
            id: maxOps
            x: -64
            visible: false
            color: themeEngine.mainHighlight1
            text: "MAX OPS"
            anchors.verticalCenter: parent.verticalCenter
            anchors.right: limit.left
            anchors.rightMargin: 10
            font.pixelSize: 18
            DesignEffect {
                id: designEffectDisplayReadoutTheme7
                visible: effectsSwitch.checked
                layerBlurRadius: 2 * root.blurFactor
                effects: [
                    DesignDropShadow {
                        id: designDropShadowReadoutTheme7
                        offsetY: 0
                        blur: 3 * root.blurFactor
                        offsetX: 0
                        color: themeEngine.mainHighlight1
                    }
                ]
            }
        }

        Text {
            id: limit
            x: -64
            visible: root.numbers.length === 8
            color: themeEngine.mainHighlight1
            text: "LIMIT"
            anchors.verticalCenter: parent.verticalCenter
            anchors.right: parent.right
            font.pixelSize: 18
            DesignEffect {
                id: designEffectDisplayReadoutTheme2
                visible: effectsSwitch.checked
                layerBlurRadius: 2 * root.blurFactor
                effects: [
                    DesignDropShadow {
                        id: designDropShadowReadoutTheme2
                        offsetY: 0
                        blur: 3 * root.blurFactor
                        offsetX: 0
                        color: themeEngine.mainHighlight1
                    }
                ]
            }
        }
    }


    /*
    DataReadout {
        id: rightReadout
        x: 832
        y: 0
        effectsOn: effectsSwitch.checked
        blurFactor: root.blurFactor
        themeString: themeEngine.themeString
        sobelOn: sobelSwitch.checked
        orthoOn: orthoSwitch.checked
        muted: muteSwitch.checked
        fps: fPS.fps
        fpsA: fPS.fpsAvg
        highlightColor: themeEngine.mainHighlight1
    }
    */
    Item {
        id: functionalComponents

        FPS {
            id: fPS
            x: 863
            y: 192
        }

        ThemeEngine {
            id: themeEngine
            dark: root.isDark
        }

        Calculator {
            id: calculator
        }

        SoundBox {
            id: soundBox
            muted: muteSwitch.checked
            volume: volumeDial.value
        }

        MusicBox {
            id: musicBox
            muted: muteSwitch.checked
            volume: volumeDial.value / 4
        }
    }

    Text {
        id: womplabel
        x: 806
        y: 1035
        opacity: 0.243
        color: themeEngine.surfaceText
        text: qsTr("WOMPULATOR 1.0")
        font.pixelSize: 18
        font.family: "Victor Mono"
        DesignEffect {
            id: designEffectSL5
            visible: root.effectsOn
            layerBlurRadius: 1.5 * root.blurFactor
            effects: [
                DesignDropShadow {
                    id: designDropShadowSL5
                    offsetY: 0
                    blur: 1 * root.blurFactor
                    offsetX: 0
                    color: themeEngine.surfaceText
                }
            ]
        }
    }

    // KEY HANDLER AND CALC INPUT CONNECTIONS
}
